==> haskell-direct-sqlite-2.3.29-103-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-direct-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 direct-sqlite
version:              2.3.29
visibility:           public
id:                   direct-sqlite-2.3.29-CiJs5ylhxm14fZIFLOedfL
key:                  direct-sqlite-2.3.29-CiJs5ylhxm14fZIFLOedfL
license:              BSD-3-Clause
copyright:
    Copyright (c) 2012 - 2014 Irene Knapp,
    2014 - 2018 Janne Hellsten,
    2018 - 2020 Sergey Bushnyak,
    2022        Joshua Chia

maintainer:           Joshua Chia <joshchia@gmail.com>
author:               Irene Knapp <irene.knapp@icloud.com>
homepage:             https://github.com/IreneKnapp/direct-sqlite
synopsis:
    Low-level binding to SQLite3.  Includes UTF8 and BLOB support.

description:
    This package is not very different from the other SQLite3 bindings out
    there, but it fixes a few deficiencies I was finding.  As compared to
    bindings-sqlite3, it is slightly higher-level, in that it supports
    marshalling of data values to and from the database.  In particular,
    it supports strings encoded as UTF8, and BLOBs represented as
    ByteStrings.

category:             Database
abi:                  924bf4d4ee1a96af8176494dbabc24bf
exposed:              True
exposed-modules:
    Database.SQLite3 Database.SQLite3.Bindings
    Database.SQLite3.Bindings.Types Database.SQLite3.Direct

import-dirs:          /usr/lib/ghc-9.4.8/site-local/direct-sqlite-2.3.29
library-dirs:         /usr/lib/ghc-9.4.8/site-local/direct-sqlite-2.3.29
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/direct-sqlite-2.3.29
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-direct-sqlite
hs-libraries:         HSdirect-sqlite-2.3.29-CiJs5ylhxm14fZIFLOedfL
extra-libraries:      sqlite3
depends:              base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-direct-sqlite/html/direct-sqlite.haddock

haddock-html:         /usr/share/doc/haskell-direct-sqlite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-direct-sqlite-2.3.29-108-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-direct-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 direct-sqlite
version:              2.3.29
visibility:           public
id:                   direct-sqlite-2.3.29-GKdoGhnZbAxQOpqTUEDvU
key:                  direct-sqlite-2.3.29-GKdoGhnZbAxQOpqTUEDvU
license:              BSD-3-Clause
copyright:
    Copyright (c) 2012 - 2014 Irene Knapp,
    2014 - 2018 Janne Hellsten,
    2018 - 2020 Sergey Bushnyak,
    2022        Joshua Chia

maintainer:           Joshua Chia <joshchia@gmail.com>
author:               Irene Knapp <irene.knapp@icloud.com>
homepage:             https://github.com/IreneKnapp/direct-sqlite
synopsis:
    Low-level binding to SQLite3.  Includes UTF8 and BLOB support.

description:
    This package is not very different from the other SQLite3 bindings out
    there, but it fixes a few deficiencies I was finding.  As compared to
    bindings-sqlite3, it is slightly higher-level, in that it supports
    marshalling of data values to and from the database.  In particular,
    it supports strings encoded as UTF8, and BLOBs represented as
    ByteStrings.

category:             Database
abi:                  72fc33ce215ffbdc40d05e94ae31a810
exposed:              True
exposed-modules:
    Database.SQLite3 Database.SQLite3.Bindings
    Database.SQLite3.Bindings.Types Database.SQLite3.Direct

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/direct-sqlite-2.3.29
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/direct-sqlite-2.3.29
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/direct-sqlite-2.3.29
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-direct-sqlite
hs-libraries:         HSdirect-sqlite-2.3.29-GKdoGhnZbAxQOpqTUEDvU
extra-libraries:      sqlite3
depends:              base-4.18.3.0 bytestring-0.11.5.4 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-direct-sqlite/html/direct-sqlite.haddock

haddock-html:         /usr/share/doc/haskell-direct-sqlite/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
